======================
 Invenio-ORCID v0.1.0
======================

Invenio-ORCID v0.1.0 was released on September 30, 2016.

About
-----

ORCID integration for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-orcid==1.0.0a1

Documentation
-------------

   http://invenio-orcid.readthedocs.io/

Happy hacking and thanks for flying Invenio-ORCID.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-orcid
|   URL: http://inveniosoftware.org
